@@ -11,15 +11,15 @@
 #'  Initializes the \code{gxs_function()} call with the arguments and default values
 #'  of the selected function.
 #'
-#'  See \code{Details} for how to set a key command.
-#' @param selection Name of function to test with gxs_function. (Character)
+#'  See \code{`Details`} for how to set a key command.
+#' @param selection Name of function to test with \code{gxs_function()}. (Character)
 #'
 #'  \strong{N.B.} Mainly intended for testing the addin programmatically.
 #' @param indentation Indentation of the selection. (Numeric)
 #'
 #'  \strong{N.B.} Mainly intended for testing the addin programmatically.
 #' @param insert Whether to insert the code via
-#'  \code{\link[rstudioapi:insertText]{rstudioapi::insertText()}}
+#'  \code{\link[rstudioapi:rstudio-documents]{rstudioapi::insertText()}}
 #'  or return them. (Logical)
 #'
 #'  \strong{N.B.} Mainly intended for testing the addin programmatically.
@@ -36,7 +36,7 @@
 #'  Parses and evaluates the selected code string
 #'  within the parent environment.
 #'  When the output is a function, it extracts the formals (arguments and default values)
-#'  and creates the initial \code{args_values} for \code{\link[xpectr:gxs_function]{gxs_function()}}.
+#'  and creates the initial \code{`args_values`} for \code{\link[xpectr:gxs_function]{gxs_function()}}.
 #'  When the output is not a function, it throws an error.
 #'  }
 #'  \subsection{How to set up a key command in RStudio}{
@@ -141,7 +141,8 @@ initializeGXSFunctionAddin <- function(selection = NULL, insert = TRUE, indentat
       "  args_values = list(\n",
       args_values_strings,
       "  ),",
-      "  indentation = 2",
+      "  indentation = 2,",
+      "  copy_env = FALSE",
       ")",
       " ",
       "#"
